@@ -9,8 +9,6 @@
 #include "structseq.h"
 #include "structmember.h"
 
-#include "fparser_docstring.h"
-
 PyObject *FlowParserError;
 PyMODINIT_FUNC initfparser(void);
 static PyObject *fparser_get_flow_iter(PyObject *self, PyObject *args,
@@ -23,11 +21,11 @@ static void trigger_on_kill_callback(struct parser_base *p);
 
 static PyTypeObject fparser_flow_id_ntuple_type = {0, 0, 0, 0, 0, 0};
 static PyStructSequence_Field flow_id_ntuple_fields[] = {
-    {"src", FP_FLOW_ID_SRC},
-    {"sport", FP_FLOW_ID_SPORT},
-    {"dest", FP_FLOW_ID_DEST},
-    {"dport", FP_FLOW_ID_DPORT},
-    {"type", FP_FLOW_ID_TYPE},
+    {"src", "The source IP address of the flow"},
+    {"sport", "The source port of the transport header of the flow"},
+    {"dest", "The destination IP address of the flow"},
+    {"dport", "The dest port of the transport header of the flow"},
+    {"type", "One of FLOW_TYPE_TCP or FLOW_TYPE_UDP"},
     {NULL}
 };
 static PyStructSequence_Desc flow_id_ntuple_desc = {
@@ -810,7 +808,7 @@ static PyMethodDef fparser_module_methods[] = {
 };
 
 static PyMethodDef fparser_methods[] = {
-    {"stop", fparser_stop, METH_VARARGS, FP_METHOD_STOP},
+    {"stop", fparser_stop, METH_VARARGS, "stops the parser"},
     {"set_tcp_callback", fparser_set_tcp_callback, METH_VARARGS,
         "Sets the TCP callback"},
     {"set_udp_callback", fparser_set_udp_callback, METH_VARARGS,
@@ -977,7 +975,7 @@ PyTypeObject fparser_type = {
 PyMODINIT_FUNC initfparser(void) {
     PyObject *m;
 
-    m = Py_InitModule3("fparser", fparser_module_methods, FP_DOCSTRING);
+    m = Py_InitModule("fparser", fparser_module_methods);
     if (m == NULL) {
         return;
     }
